NetLand Script V2.0 — File Browser

NetLandScriptV2.0 / NetLandScriptV2.0 / remote / logviews.mrc

logviews.mrc — 11.44 KB — Download this file

;====================================================================================
;                                                                 NetLand §¢®Ipt V2.0
;                                                                       ßÿ GoodNews 
;                                           We made everything here and it is professional
;                                          so you dont need to touch or change  anything 
;                                     cause it can cause a malfunction to the script .Thx !!!!!!
;                                                               Long Live #NetLand
;=====================================================================================
alias logviews.about {
  if ($window(@logviews) == $null) { set %logviews.about run | logviews }
  else {
    clear @logviews
    titlebar @logviews - About
    aline @logviews 11,1Log Viewer V1.0 ßy GoodNews For #NetLand 
    aline @logviews $chr(160)
    aline -p @logviews $str($chr(160),4) 11,1Log Viewer allows you to manage your IRC logs quickly and easily. You now do not have to open up notepad to view every single log anymore. With Log Viewer you can open each log in full color right in mIRC!
    aline @logviews $chr(160)
    aline @logviews $chr(160)  11,1NetLand §¢®Ipt V2.0  ßy GoodNews 
    aline @logviews $chr(160)
  }
} 

alias logviews {
  :start
  set %logviews.window.h $window(-1).h
  set %logviews.window.w $window(-1).w
  if ($window(@logviews) == $null) {  
    window -l16 @logviews 200 200 630 200 @logviews Arial 11
    window -nls @logviews2 Arial 11
    aline @logviews 11,1Log Organiser %logviews.version Loading log database please wait............................................. 
    set %logviews.count 1
    :AddLog
    set %logviews.log $findfile($logdir,*.log,%logviews.count)
    if (%logviews.log == $null) goto end
    else {
      aline -l @logviews2 $nopath(%logviews.log)
      inc %logviews.count 1
      goto addlog
    }
  }
  else { window -c @logviews | goto start }
  :end
  set %logviews.lines $line(@logviews2,0,0)
  set %logviews.count 1
  :lineadd
  if (%logviews.count > %logviews.lines) goto end2
  else {
    aline -l @logviews $line(@logviews2,%logviews.count)
    inc %logviews.count 1
    goto lineadd
  }
  :end2
  if (%logviews.about == run) { logviews.about | set %logviews.about ran | goto end4 }
  :end3
  clear @logviews
  aline @logviews 11,1Log Viewer V1.0 ßy GoodNews For NetLand §¢®Ipt 
  aline @logviews $chr(160)
  aline -p @logviews $str($chr(160),4) 11,1Welcome To Log Viewer V1.0  $+ !  To view a log, please double click it in the side listbox.  Or else  right click on a log in the listbox to access more commands.
  :end4                              
  iline -l @logviews 1 11,1¥¥¥¥¥¥¥¥¥¥¥¥¥¥¥¥¥¥¥
  iline -l @logviews 2 1,1.....11,1NetLand §¢®Ipt1,1.........  $chr(160) $str($chr(160),30)
  iline -l @logviews 3 1,1.......11,1Current Logs 1,1...........
  iline -l @logviews 4 11,1¥¥¥¥¥¥¥¥¥¥¥¥¥¥¥¥¥¥¥
  window -c @logviews2
}

alias logrefresh {
  :start
  if ($window(@logviews) == $null) { logviews }
  else {
    clear -l @logviews
    window -nls @logviews2 Arial 11
    set %logviews.count 1
    :AddLog
    set %logviews.log $findfile($logdir,*.log,%logviews.count)
    if (%logviews.log == $null) goto end
    else {
      aline -l @logviews2 $nopath(%logviews.log)
      inc %logviews.count 1
    goto addlog }
  }
  :end
  set %logviews.lines $line(@logviews2,0,0)
  set %logviews.count 1
  :lineadd
  if (%logviews.count > %logviews.lines) goto end2
  else {
    aline -l @logviews $line(@logviews2,%logviews.count)
    inc %logviews.count 1
    goto lineadd
  }
  :end2
  iline -l @logviews 1 11,1 $chr(160) Current Logs  $str($chr(160),30)
  iline -l @logviews 2 11,1 $str($chr(160),175) 
  window -c @logviews2
}

alias Logview {
  if ($sline(@logviews,1).ln == 1 || $sline(@logviews,1).ln == 2) { halt }
  else {
    set %logviews.file $logdir $+ $sline(@logviews,1)
    set %logviews.size $lof(%logviews.file)
    clear @logviews    
    iline @logviews 1 11,1Log Viewer V1.0 ßy GoodNews For...............11,1NetLand §¢®Ipt   Viewing: $sline(@logviews,1) ( $+ %logviews.size bytes) $str($chr(160),175)
    titlebar @logviews - $sline(@logviews,1)
    loadbuf -p @logviews $logdir $+ $sline(@logviews,1)
    sline @logviews 15
  }
}

alias logview.newwindow {
  set %logviews.window @ [ $+ [ $sline(@logviews,1) ] ]
  set %logviews.file $logdir $+ $sline(@logviews,1)
  set %logviews.size $lof(%logviews.file)
  window %logviews.window @LogView Arial 11
  iline %logviews.window 1 11,1Log Viewer V1.0 ßy GoodNews For......................  11,1NetLand §¢®Ipt11,1 Viewing: $sline(@logviews,1) ( $+ %logviews.size bytes) $str($chr(160),175)
  loadbuf %logviews.window $logdir $+ $sline(@logviews,1)
  sline %logviews.window 15
}

menu @logviews {
  dclick loglist2 
  About:logviews.about
  -
  Search Log Text:logsearch
  View Log:logview $sline(@logviews,1)
  -
  Delete Log:dellog $sline(@logviews,1)
  Copy Log:copylog
  Rename Log:remlog
  -
  Refresh List:logrefresh
  -
  Close Window:window -c @logviews
  -
}

alias LogList2 {
  if ($sline(@logviews,1).ln == 1 || $sline(@logviews,1).ln == 2 || $sline(@logviews,1).ln == $null) { halt }
  else logview $sline(@logviews,1)
}

menu @Logview {
  Search Log Text:logsearch.nw
  -
  Delete Log:/dellog $remove($active,@)
  Copy Log:/copylog
  -
  Close Window:window -c $active
  -
  About:window -a @logviews | logviews.about
}

menu @Confirm.Delete {
  dclick Confirm.Delete
}

alias Confirm.Delete {
  if ($sline(@Confirm.Delete,1).ln == 1 || $sline(@Confirm.Delete,1).ln == 2 || $sline(@Confirm.Delete,1).ln == 3 || $sline(@Confirm.Delete,1).ln == 4) { halt }
  if ($sline(@Confirm.Delete,1).ln == 5) { remove $logdir $+ %logviews.log.delete | window -c @Confirm.Delete | dline -l @logviews $sline(@logviews,1).ln | echo 11,1»»»11,1Log Organiser %logviews.version 11,1 %logviews.log.delete 11,1 DELETED }
  if ($sline(@Confirm.Delete,1).ln == 6) { window -c @Confirm.Delete }
}

alias copylog {
  if ($sline(@logviews,1).ln == 1 || $sline(@logviews,1).ln == 2 || $sline(@logviews,1).ln == $null) { halt }
  /copy $logdir $+ $sline(@logviews,1) $sdir="Select A Directory To Copy $sline(@logviews,1) To:" $+ $sline(@logviews,1)
}

alias remlog {
  if ($sline(@logviews,1).ln == 1 || $sline(@logviews,1).ln == 2 || $sline(@logviews,1).ln == $null) { halt }
  else {
    rename $logdir $+ $sline(@logviews,1) $logdir $+ $?="Please Enter A New File Name:" | logrefresh
  }
}

alias dellog {
  if ($sline(@logviews,1).ln == 1 || $sline(@logviews,1).ln == 2 || $sline(@logviews,1).ln == $null) { halt } 
  else {
    set %logviews.log.delete $sline(@logviews,1)
    window -l+bt @Confirm.Delete 20 20 150 111 @Confirm.Delete Arial 11
    aline @Confirm.Delete 11,1 Hey11,1 Are you 11,1sure11,1 you want $str($chr(160),10)
    aline @Confirm.Delete 11,1 to delete: $str($chr(160),50)
    aline @Confirm.Delete 11,1 $sline(@logviews,1) $+ ? $str($chr(160),100)
    aline @Confirm.Delete 1 ***********************************
    aline @Confirm.Delete 11,1 YES $str($chr(160),50)
    aline @Confirm.Delete 11,1 NO $str($chr(160),50)
  }
}

alias dellog2 {
  set %logviews.log.delete $remove($active,@)
  window -l+bt @Confirm.Delete 20 20 150 111 @Confirm.Delete Arial 11
  aline @Confirm.Delete 11,1NetLand §¢®Ipt11,1 v1.011,1 ßy GoodNews 11,1%11,1 Log Viewer V1.0 11,1NetLand §¢®Ipt11,1 v1.011,1 ßy GoodNews 
  aline @Confirm.Delete 11,1 **************************************
  aline @Confirm.Delete 11,1 Are you 11,1sure11,1 you want $str($chr(160),10)
  aline @Confirm.Delete 11,1 to delete: $str($chr(160),50)
  aline @Confirm.Delete 11,1 $sline(@logviews,1) $+ ? $str($chr(160),100)
  aline @Confirm.Delete 11,1 ***************************************
  aline @Confirm.Delete 11,1 YES $str($chr(160),50)
  aline @Confirm.Delete 11,1 NO $str($chr(160),50)
}

menu @Confirm.Delete2 {
  dclick Confirm.Delete2
}

alias Confirm.Delete2 {
  if ($sline(@Confirm.Delete,1).ln == 1 || $sline(@Confirm.Delete,1).ln == 2 || $sline(@Confirm.Delete,1).ln == 3 || $sline(@Confirm.Delete,1).ln == 4) { halt }
  if ($sline(@Confirm.Delete,1).ln == 5) { remove $logdir $+ %logviews.log.delete | window -c @Confirm.Delete | logrefresh | echo -a 11,1Log Organiser %logviews.version -11,1 %logviews.log.delete11,1 DELETED! }
  if ($sline(@Confirm.Delete,1).ln == 6) { window -c @Confirm.Delete }
}

alias lognotepad {
  if ($sline(@logviews,1).ln == 1 || $sline(@logviews,1).ln == 2 || $sline(@logviews,1).ln == $null) { halt }
  else run notepad.exe $logdir $+ $sline(@logviews,1)
}

alias logsearch {
  if ($window(@logviews).title == - $sline(@logviews,1)) goto next
  else { logview $sline(@logviews,1) | goto next }
  :next
  if ($window(@LogSearch) != $null) /window -c @LogSearch
  window @LogSearch @LogSearch Arial 11
  set %logviews.file $logdir $+ $sline(@logviews,1)
  titlebar @LogSearch - $sline(@logviews,1) 
  set %logviews.searchstring * [ $+ [ $?="Enter Text To Search For:" ] $+ ] *
  aline @LogSearch 11,1Log Viewer V1.0 ßy GoodNews  For NetLand §¢®Ipt   $str($chr(160),10) 11,1 Log Searcher
  aline @LogSearch 11,1 $str($chr(160),20) Searching For:11,1 %logviews.searchstring 
  filter -fwn %logviews.file @LogSearch %logviews.searchstring
}

menu @LogSearch {
  dclick logsearch2
  Goto Line:logsearch2
  -
  Close Window:window -c @LogSearch
  About:window -a @logviews | logviews.about
} 

alias logsearch2 {
  if ($sline(@LogSearch,1).ln == 1 || $sline(@LogLogSearch,1).ln == 2 || $sline(@LogSearch,1).ln == $null) { halt }
  else {
    sline @logviews $calc($gettok($sline(@LogSearch,1),1,32) + 10)
    window -a @logviews
  }
}

alias logsearch.nw {
  set %logviews.window $remove($active,@)
  if ($window(@LogSearch) != $null) window -c @LogSearch
  window -l @LogSearch @LogSearch.nw Arial 11
  set %logviews.file $logdir $+ %logviews.window
  titlebar @LogSearch - %logviews.window
  set %logviews.searchstring * [ $+ [ $?="Enter Text To Search For:" ] $+ ] *
  aline @LogSearch 11,1 Log Organiser %logviews.version  $str($chr(160),150) 11,1Log Searcher $str($chr(160),100)
  aline @LogSearch 11,1 $str($chr(160),20) Searching For:11,1 %logviews.searchstring  $str($chr(160),500)
  filter -fwn %logviews.file @LogSearch %logviews.searchstring
}

menu @LogSearch.nw {
  dclick:logsearchnw
  Goto Line:logsearchnw
  -
  Close Window:window -c @LogSearch
  About:window -a @logviews | logviews.about
} 

alias logsearchnw {
  set %logviews.window2 @ $+ %logviews.window
  if ($sline(@LogSearch,1).ln == 1 || $sline(@LogLogSearch,1).ln == 2 || $sline(@LogSearch,1).ln == $null) { halt }
  else {
    sline %logviews.window2 $calc($gettok($sline(@LogSearch,1),1,32) + 10)
    window -a %logviews.window2
  }
}
alias bw_mod_e {
  if ($1 == $null) { halt }
  %bw_wtot = $count(%badwords,$chr(44)) + 1
  :bwm_Wloop
  if (%bw_wtot =< 0) { bw_winit | halt }
  elseif ($gettok(%badwords,%bw_wtot,44) == $1) { dline %bw_wset $sline(%bw_wset,1).ln | %badwords = $remtok(%badwords,$1,44) | halt }
  else { dec %bw_wtot | goto bwm_Wloop }
}

alias Wordalc {
  %bw_alt = $count($1,$chr(44)) + 1
  :alcloop
  if (%bw_alt <= 0) { return }
  else { 
    aline $2 $gettok($1,%bw_alt,44)
    dec %bw_alt
    goto alcloop
  }
  :end
}